@@ -21,10 +21,10 @@ class ContactGroupWrapper : public QObject, public Akonadi::ItemMonitor
     Q_PROPERTY(QAbstractListModel *model READ model CONSTANT)
 
 public:
-    ContactGroupWrapper(QObject *parent = nullptr);
-    QString name() const;
+    explicit ContactGroupWrapper(QObject *parent = nullptr);
+    [[nodiscard]] QString name() const;
     void setName(const QString &name);
-    Akonadi::Item item() const;
+    [[nodiscard]] Akonadi::Item item() const;
     void setItem(const Akonadi::Item &item);
     QAbstractListModel *model() const;
 
@@ -40,6 +40,6 @@ private:
     void loadContactGroup(const KContacts::ContactGroup &contactGroup);
 
     QString m_name;
-    ContactGroupModel *m_model;
+    ContactGroupModel *const m_model;
     Akonadi::Item m_item;
-};
\ No newline at end of file
+};
