@@ -23,8 +23,8 @@ public:
     QVariant data(const QModelIndex &index, int role) const override;
     Qt::ItemFlags flags(const QModelIndex &index) const override;
     QHash<int, QByteArray> roleNames() const override;
-    QColor getCollectionColor(Akonadi::Collection collection) const;
-    QColor color(Akonadi::Collection::Id collectionId) const;
+    [[nodiscard]] QColor getCollectionColor(Akonadi::Collection collection) const;
+    [[nodiscard]] QColor color(Akonadi::Collection::Id collectionId) const;
     void setColor(Akonadi::Collection::Id collectionId, const QColor &color);
 
     void setStandardCollectionId(Akonadi::Collection::Id standardCollectionId);
